@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2010 - 2018, Met Office
+# (C) British Crown Copyright 2010 - 2019, Met Office
 #
 # This file is part of Iris.
 #
@@ -121,7 +121,7 @@ except ImportError:
 
 
 # Iris revision.
-__version__ = '2.2.1dev0'
+__version__ = '2.3.0'
 
 # Restrict the names imported when using "from iris import *"
 __all__ = ['load', 'load_cube', 'load_cubes', 'load_raw',
@@ -337,7 +337,9 @@ def load(uris, constraints=None, callback=None):
         A modifier/filter function.
 
     Returns:
-        An :class:`iris.cube.CubeList`.
+        An :class:`iris.cube.CubeList`. Note that there is no inherent order
+        to this :class:`iris.cube.CubeList` and it should be treated as if it
+        were random.
 
     """
     return _load_collection(uris, constraints, callback).merged().cubes()
@@ -370,8 +372,7 @@ def load_cube(uris, constraint=None, callback=None):
     if len(constraints) != 1:
         raise ValueError('only a single constraint is allowed')
 
-    cubes = _load_collection(uris, constraints, callback)
-    cubes = cubes.merged().cubes()
+    cubes = _load_collection(uris, constraints, callback).cubes()
 
     try:
         cube = cubes.merge_cube()
@@ -403,7 +404,9 @@ def load_cubes(uris, constraints=None, callback=None):
         A modifier/filter function.
 
     Returns:
-        An :class:`iris.cube.CubeList`.
+        An :class:`iris.cube.CubeList`. Note that there is no inherent order
+        to this :class:`iris.cube.CubeList` and it should be treated as if it
+        were random.
 
     """
     # Merge the incoming cubes
