@@ -1,4 +1,4 @@
-# (C) British Crown Copyright 2014 - 2016, Met Office
+# (C) British Crown Copyright 2014 - 2017, Met Office
 #
 # This file is part of Iris.
 #
@@ -23,13 +23,11 @@ from six.moves import (filter, input, map, range, zip)  # noqa
 # importing anything else.
 import iris.tests as tests
 
-from subprocess import check_output
-
 from cf_units import Unit
 import numpy.ma as ma
 
 import iris
-from iris import FUTURE, load_cube, save
+from iris import load_cube, save
 from iris.coords import CellMethod, DimCoord
 from iris.coord_systems import RotatedGeogCS
 from iris.fileformats.pp import EARTH_RADIUS as UM_DEFAULT_EARTH_RADIUS
@@ -38,41 +36,33 @@ from iris.util import is_regular
 
 # Grib support is optional.
 if tests.GRIB_AVAILABLE:
-    try:
-        # Try to load the independent 'iris_grib' package.
-        from iris_grib import load_pairs_from_fields
-        from iris_grib.message import GribMessage
-    except ImportError:
-        # Try to load old inbuilt module instead.
-        from iris.fileformats.grib import load_pairs_from_fields
-        from iris.fileformats.grib.message import GribMessage
+    from iris_grib import load_pairs_from_fields
+    from iris_grib.message import GribMessage
 
 
 @tests.skip_data
 @tests.skip_grib
 class TestImport(tests.IrisTest):
     def test_gdt1(self):
-        with FUTURE.context(strict_grib_load=True):
-            path = tests.get_data_path(('GRIB', 'rotated_nae_t',
-                                        'sensible_pole.grib2'))
-            cube = load_cube(path)
-            self.assertCMLApproxData(cube)
+        path = tests.get_data_path(('GRIB', 'rotated_nae_t',
+                                    'sensible_pole.grib2'))
+        cube = load_cube(path)
+        self.assertCMLApproxData(cube)
 
     def test_gdt90_with_bitmap(self):
-        with FUTURE.context(strict_grib_load=True):
-            path = tests.get_data_path(('GRIB', 'umukv', 'ukv_chan9.grib2'))
-            cube = load_cube(path)
-            # Pay particular attention to the orientation.
-            self.assertIsNot(cube.data[0, 0], ma.masked)
-            self.assertIs(cube.data[-1, 0], ma.masked)
-            self.assertIs(cube.data[0, -1], ma.masked)
-            self.assertIs(cube.data[-1, -1], ma.masked)
-            x = cube.coord('projection_x_coordinate').points
-            y = cube.coord('projection_y_coordinate').points
-            self.assertGreater(x[0], x[-1])  # Decreasing X coordinate
-            self.assertLess(y[0], y[-1])  # Increasing Y coordinate
-            # Check everything else.
-            self.assertCMLApproxData(cube)
+        path = tests.get_data_path(('GRIB', 'umukv', 'ukv_chan9.grib2'))
+        cube = load_cube(path)
+        # Pay particular attention to the orientation.
+        self.assertIsNot(cube.data[0, 0], ma.masked)
+        self.assertIs(cube.data[-1, 0], ma.masked)
+        self.assertIs(cube.data[0, -1], ma.masked)
+        self.assertIs(cube.data[-1, -1], ma.masked)
+        x = cube.coord('projection_x_coordinate').points
+        y = cube.coord('projection_y_coordinate').points
+        self.assertGreater(x[0], x[-1])  # Decreasing X coordinate
+        self.assertLess(y[0], y[-1])  # Increasing Y coordinate
+        # Check everything else.
+        self.assertCMLApproxData(cube)
 
 
 @tests.skip_data
@@ -82,8 +72,7 @@ class TestPDT8(tests.IrisTest):
         # Load from the test file.
         file_path = tests.get_data_path(('GRIB', 'time_processed',
                                          'time_bound.grib2'))
-        with FUTURE.context(strict_grib_load=True):
-            self.cube = load_cube(file_path)
+        self.cube = load_cube(file_path)
 
     def test_coords(self):
         # Check the result has main coordinates as expected.
@@ -161,8 +150,7 @@ class TestPDT40(tests.IrisTest):
 
         with self.temp_filename('test_grib_pdt40.grib2') as temp_file_path:
             save(cube, temp_file_path)
-            with FUTURE.context(strict_grib_load=True):
-                loaded = load_cube(temp_file_path)
+            loaded = load_cube(temp_file_path)
             self.assertEqual(loaded.attributes, cube.attributes)
 
 
@@ -212,10 +200,9 @@ class TestGDT5(tests.TestGribMessage):
             self.assertGribMessageContents(temp_file_path, expect_values)
 
             # Load the Grib file back into a new cube.
-            with FUTURE.context(strict_grib_load=True):
-                cube_loaded_from_saved = load_cube(temp_file_path)
-                # Also load data, before the temporary file gets deleted.
-                cube_loaded_from_saved.data
+            cube_loaded_from_saved = load_cube(temp_file_path)
+            # Also load data, before the temporary file gets deleted.
+            cube_loaded_from_saved.data
 
         # The re-loaded result will not match the original in every respect:
         #  * cube attributes are discarded
@@ -280,8 +267,7 @@ class TestGDT30(tests.IrisTest):
 
     def test_lambert(self):
         path = tests.get_data_path(('GRIB', 'lambert', 'lambert.grib2'))
-        with FUTURE.context(strict_grib_load=True):
-            cube = load_cube(path)
+        cube = load_cube(path)
         self.assertCMLApproxData(cube)
 
 
@@ -291,14 +277,12 @@ class TestGDT40(tests.IrisTest):
 
     def test_regular(self):
         path = tests.get_data_path(('GRIB', 'gaussian', 'regular_gg.grib2'))
-        with FUTURE.context(strict_grib_load=True):
-            cube = load_cube(path)
+        cube = load_cube(path)
         self.assertCMLApproxData(cube)
 
     def test_reduced(self):
         path = tests.get_data_path(('GRIB', 'reduced', 'reduced_gg.grib2'))
-        with FUTURE.context(strict_grib_load=True):
-            cube = load_cube(path)
+        cube = load_cube(path)
         self.assertCMLApproxData(cube)
 
 
@@ -309,8 +293,7 @@ class TestDRT3(tests.IrisTest):
     def test_grid_complex_spatial_differencing(self):
         path = tests.get_data_path(('GRIB', 'missing_values',
                                     'missing_values.grib2'))
-        with FUTURE.context(strict_grib_load=True):
-            cube = load_cube(path)
+        cube = load_cube(path)
         self.assertCMLApproxData(cube)
 
 
