@@ -23,8 +23,11 @@ from __future__ import (absolute_import, division, print_function)
 from six.moves import (filter, input, map, range, zip)  # noqa
 import six
 
+try:  # Python 3
+    from collections.abc import Hashable
+except ImportError:  # Python 2.7
+    from collections import Hashable
 import abc
-import collections
 from contextlib import contextmanager
 import copy
 import functools
@@ -160,6 +163,7 @@ def delta(ndarray, dimension, circular=False):
         _delta = np.roll(ndarray, -1, axis=dimension)
         last_element = [slice(None, None)] * ndarray.ndim
         last_element[dimension] = slice(-1, None)
+        last_element = tuple(last_element)
 
         if not isinstance(circular, bool):
             result = np.where(ndarray[last_element] >= _delta[last_element])[0]
@@ -834,7 +838,7 @@ class _MetaOrderedHashable(abc.ABCMeta):
 
 @functools.total_ordering
 class _OrderedHashable(six.with_metaclass(_MetaOrderedHashable,
-                                          collections.Hashable)):
+                                          Hashable)):
     """
     Convenience class for creating "immutable", hashable, and ordered classes.
 
@@ -1637,18 +1641,17 @@ def find_discontiguities(cube, rel_tol=1e-5, abs_tol=1e-8):
         discontiguities in the coordinate points array.
 
         This can be used as the input array for
-        :func:`iris.util.mask_discontiguities`.
+        :func:`iris.util.mask_cube`.
 
     Examples::
 
         # Find any unknown discontiguities in your cube's x and y arrays:
         discontiguities = iris.util.find_discontiguities(cube)
 
-        # Pass the resultant boolean array to `iris.util.mask_discontiguities`
+        # Pass the resultant boolean array to `iris.util.mask_cube`
         # with a cube slice; this will use the boolean array to mask
         # any discontiguous data points before plotting:
-        masked_cube_slice = iris.util.mask_discontiguities(cube[0],
-                                                           discontiguities)
+        masked_cube_slice = iris.util.mask_cube(cube[0], discontiguities)
 
         # Plot the masked cube slice:
         iplt.pcolormesh(masked_cube_slice)
